@@ -44,7 +44,9 @@ class _Configuration(object):
 		"last_updatecheck"			: (datetime, LONG_AGO),
 		"window_position"			: (tuple, None),
 		"infobox_style"				: (str, 'font_weight="bold" font_size="large"'),
+		"icon_theme"				: (str, 'syncthing'),
 		"force_dark_theme"			: (bool, False),	# Windows-only
+		"language"					: (str, ""),		# Windows-only
 	}
 	
 	# Overrides some default values on Windows
